Module cdxlib::column[][src]

Handles conversion between named column sets and lists of column numbers Also helps with selecting those columns from a line of text

Structs

Write the columns with a custom delimiter

A column set is a collection of column specifictions, which when interpreted in the context of a set of named columns, produces a list of column numbers It contains a bunch of “yes” specs and “no” specs. If there are no “yes” specs, all columns are marked “yes” The resulting list of column numbers is all of the “yes” columns in order, minus any “no” columns. Thus if a column appears in both, it will be excluded.

a column, by name or number

Selection of columns from a Reader

A collection of ColumnFun writers

Traits

Write some output